@@ -1,8 +1,15 @@
-import collections, types, re, functools
+from __future__ import print_function, unicode_literals
+
+import sys, collections, types, re, functools
 from unittest.case import TestCase
 from collections import namedtuple, Mapping, Iterable
 
-__all__ = ['EnsureError', 'Ensure', 'Check', 'ensure', 'check', 'ensure_raises', 'ensure_raises_regex']
+USING_PYTHON2 = True if sys.version_info < (3, 0) else False
+
+__all__ = ['EnsureError', 'Ensure', 'Check', 'ensure', 'check', 'ensure_raises', 'ensure_raises_regex', 'ensure_annotations']
+
+if USING_PYTHON2:
+    __all__ = map(bytes, __all__)
 
 try:
     from repr import Repr
@@ -484,6 +491,8 @@ class Ensure(Inspector):
         except self._catch as err:
             raise self._error_factory(_format("Expected {} to be greater than {}", self._subject, other))
 
+    exceeds = is_greater_than
+
     def is_less_than(self, other):
         """
         Ensures :attr:`subject` is less than *other*.
@@ -630,7 +639,11 @@ def ensure_annotations(f):
                 if arg_pos is None:
                     arg_pos = {arg: pos for pos, arg in enumerate(f.__code__.co_varnames)}
                 if arg in arg_pos:
-                    value = args[arg_pos[arg]]
+                    pos = arg_pos[arg]
+                    if len(args) > pos:
+                        value = args[pos]
+                    else:
+                        continue
                 else:
                     continue
             if not isinstance(value, templ):
