@@ -1,14 +1,13 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
 
 import os, sys, unittest, collections, copy, re
 
 sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
 from ensure import *
 
-
 class TestEnsure(unittest.TestCase):
     def test_basic_ensure_statements(self):
         ensure(range(10)).contains(5)
@@ -40,6 +39,7 @@ class TestEnsure(unittest.TestCase):
                       'Ensure(x).is_a_dict_of(int).to(int)',
                       'Ensure(x).is_a(collections.Mapping).of(int).to(int)',
                       'Ensure(6).is_greater_than(5)',
+                      'Ensure(6).exceeds(5)',
                       'Ensure(1.1).is_greater_than_or_equal_to(1.1)',
                       'Ensure(1.1).is_less_than_or_equal_to(1.1)',
                       'Ensure(1).is_less_than(1.1)',
@@ -81,6 +81,7 @@ class TestEnsure(unittest.TestCase):
                        'Ensure(x).is_a(str)',
                        'Ensure(x).is_empty()',
                        'Ensure(6).is_greater_than(7)',
+                       'Ensure(6).exceeds(7)',
                        'Ensure(1).is_greater_than_or_equal_to(1.1)',
                        'Ensure(None).is_greater_than_or_equal_to(1.1)',
                        'Ensure(5).is_less_than_or_equal_to(1)',
@@ -131,11 +132,15 @@ class TestEnsure(unittest.TestCase):
         f_code = """
 from ensure import ensure_annotations
 
-global f
+global f, g
 
 @ensure_annotations
 def f(x: int, y: float) -> float:
     return x+y if x+y > 0 else int(x+y)
+
+@ensure_annotations
+def g(x: str, y: str="default") -> str:
+    return x+y
 """
         exec(f_code)
         self.assertEqual(f(1, 2.3), 3.3)
@@ -150,5 +155,10 @@ def f(x: int, y: float) -> float:
         with self.assertRaisesRegexp(EnsureError, "Return value of <function f at .+> does not match annotation type <class 'float'>"):
             self.assertEqual(f(x=1, y=-2.3), 4)
 
+        # Test with mixtures of keyword and positional args
+        self.assertEqual(g("the "), "the default")
+        self.assertEqual(g("the ", "bomb"), "the bomb")
+        self.assertEqual(g(y=g("the ", y="bomb"), x="somebody set up us "), "somebody set up us the bomb")
+
 if __name__ == '__main__':
     unittest.main()
